@@ -9,7 +9,7 @@ use Scalar::Util qw(weaken);
 use Carp qw(croak);
 
 our $STOP = {};
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 our @ATTR = qw(	id direction_out direction_in direction_out_link direction_in_link
 		description_out description_in name operator operator_ph );
 
@@ -45,10 +45,10 @@ sub __get_tt {
         my( $self, $direction ) = @_; 
 	return unless $direction =~ /(in|out)/;
 
-	my $tt = $self->__request( ( $direction eq 'out' ? $self->{direction_out_link} : $self->{direction_in} ) );
+	my $tt = $self->__request( ( $direction eq 'out' ? $self->{direction_out_link} : $self->{direction_in_link} ) );
 	my $t = HTML::TreeBuilder->new_from_content( $tt );
 	#my $tt = HTML::TreeBuilder->new_from_file( './metro_bus_route_235_tt_out_full' );
-	my $t = $tt;
+	#my $t = $tt;
 
 	for ( $t->look_down( _tag => 'meta' ) ) {
 		if( ( defined $_->attr( 'http-equiv' ) ) and ( $_->attr( 'http-equiv' ) eq 'refresh' ) ) {
@@ -68,7 +68,7 @@ sub __get_tt {
 		$t = HTML::TreeBuilder->new_from_content( $self->__request( "http://tt.ptv.vic.gov.au/tt/$tt" ) )
 	}
 
-	$t = $t->look_down( _tag => 'div', id => qr/tt(Bus|Tram|Train)/ );
+	$t = $t->look_down( _tag => 'div', id => qr/tt(Bus|Tram|Train|Regional)/ );
 	my @stops = $t->look_down( _tag => 'div', class => qr/^ma_stop/ );
 	my @stop_names = map { $_->as_text } @stops;
 	my @stop_links = map { my ($r) = $_->look_down( _tag => 'a' )->attr( 'href' ) =~ /.*\/(\d*$)/ } @stops;
